==> fuel-ui-0.4.1-3.tgz: package/esm/pipes/pipes.demo.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FormsModule } from "@angular/forms";
import { FuelUiModule } from "../fuel-ui";
import { FormatDemo } from "./format/format.demo";
import { MapToIterableDemo } from "./mapToIterable/mapToIterable.demo";
import { OrderByDemo } from "./orderBy/orderBy.demo";
import { RangeDemo } from "./range/range.demo";
export * from "./format/format.demo";
export * from "./mapToIterable/mapToIterable.demo";
export * from "./orderBy/orderBy.demo";
export * from "./range/range.demo";
const demoDirectives = [
    FormatDemo,
    MapToIterableDemo,
    OrderByDemo,
    RangeDemo
];
export let FuiPipesDemoModule = class FuiPipesDemoModule {
};
FuiPipesDemoModule = __decorate([
    NgModule({
        imports: [CommonModule, FormsModule, FuelUiModule],
        declarations: demoDirectives,
        exports: demoDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiPipesDemoModule);

==> fuel-ui-0.4.1-4.tgz: package/esm/pipes/pipes.demo.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FormsModule } from "@angular/forms";
import { FuelUiModule } from "../fuel-ui";
import { FormatDemo } from "./Format/Format.Demo";
import { MapToIterableDemo } from "./MapToIterable/MapToIterable.Demo";
import { OrderByDemo } from "./OrderBy/OrderBy.Demo";
import { RangeDemo } from "./Range/Range.Demo";
export * from "./Format/Format.Demo";
export * from "./MapToIterable/MapToIterable.Demo";
export * from "./OrderBy/OrderBy.Demo";
export * from "./Range/Range.Demo";
const demoDirectives = [
    FormatDemo,
    MapToIterableDemo,
    OrderByDemo,
    RangeDemo
];
export let FuiPipesDemoModule = class FuiPipesDemoModule {
};
FuiPipesDemoModule = __decorate([
    NgModule({
        imports: [CommonModule, FormsModule, FuelUiModule],
        declarations: demoDirectives,
        exports: demoDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiPipesDemoModule);
